Learn R Programming

ggcorrheatmap (version 0.3.0)

add_split_diag: Draw triangles in the diagonal to split the it between the two triangles of a square matrix.

Description

Draw triangles in the diagonal to split the it between the two triangles of a square matrix.

Usage

add_split_diag(
  plt,
  x_long,
  lt,
  border_col = "grey",
  border_lwd = 0.1,
  border_lty = 1
)

Value

ggplot object with added triangles in the diagonal.

Arguments

plt

Plot object to add to.

x_long

Plotting data for the diagonal.

lt

Layout of the heatmap.

border_col

Cell border colour.

border_lwd

Cell border linewidth.

border_lty

Cell border linetype.