Draw triangles in the diagonal to split the it between the two triangles of a square matrix.
add_split_diag(
plt,
x_long,
lt,
border_col = "grey",
border_lwd = 0.1,
border_lty = 1
)ggplot object with added triangles in the diagonal.
Plot object to add to.
Plotting data for the diagonal.
Layout of the heatmap.
Cell border colour.
Cell border linewidth.
Cell border linetype.