Make main heatmap part of plot for gghm.
make_heatmap(
x_long,
plt = NULL,
mode = "heatmap",
include_diag = TRUE,
invisible_diag = FALSE,
border_lwd = 0.1,
border_col = "grey",
border_lty = 1,
show_names_diag = TRUE,
show_names_cols = FALSE,
show_names_rows = FALSE,
names_cols_side = "top",
names_rows_side = "left",
col_scale = NULL,
size_scale = NULL,
cell_labels = FALSE,
cell_label_col = "black",
cell_label_size = 3,
cell_label_digits = 2,
cell_bg_col = "white",
cell_bg_alpha = 0,
split_rows_names = FALSE,
split_cols_names = FALSE,
split_rows_side = "right",
split_cols_side = "bottom",
split_diag = FALSE
)ggplot object with heatmap component.
Long format data.
A ggplot object to build onto. If NULL, makes a new plot.
Plotting mode.
Logical indicating if diagonal should be included.
Logical indicating if an invisible diagonal should be included.
Border linewidth.
Border colour.
Border linetype.
Logical indicating if names should be displayed on the diagonal.
Logical indicating if names should be displayed on the x axis.
Logical indicating if names should be displayed on the y axis.
X axis side.
Y axis side.
Scale for colour/fill aesthetic.
Scale for size aesthetic.
Data frame of text to write on cells (processed by check_cell_labels).
Colour of cell labels.
Size of cell labels.
Number of digits for cell labels if numeric.
Cell background colour (fill).
Cell background alpha.
Logicals indicating if the facet names should be shown (if plot is built from scratch).
Sides to put the facet strips.
Logical indicating if the diagonal should be drawn as triangles (to split it between the two halves).