If a mixed layout uses the same aesthetic for both triangles and only one (or no) colour or size scale has been specified, remove redundant scales.
remove_duplicate_scales(
scale_vec,
col_scale = NULL,
size_scale = NULL,
bins,
limits,
high,
mid,
low,
na_col,
midpoint,
size_range
)Vector of aesthetics with duplicates removed if appropriate.
Vector of scale aesthetics.
Input colour scales (NULL, string or scale object).
Input size scales.
Numeric for number of bins to determine if multiple scales are needed (if multiple bins values).
Limits of scale (list of limits if two scales).
Colours at high values (correlation heatmap).
Colours at medium values (correlation heatmap).
Colours at low values (correlation heatmap).
Colour if NA.
Midpoint of divergent scale (correlation heatmap).
Size range (list of ranges if two scales).